@@ -3,7 +3,11 @@ from typing import Optional
 
 
 class Config(BaseModel, extra=Extra.ignore):
+    xhs_ck: Optional[str] = ''
     douyin_ck: Optional[str] = ''
     is_oversea: Optional[bool] = False
     is_lagrange: Optional[bool] = False
-    resolver_proxy: Optional[str] = 'http://127.0.0.1:7890'
\ No newline at end of file
+    bili_sessdata: Optional[str] = ''
+    r_global_nickname: Optional[str] = ''
+    resolver_proxy: Optional[str] = 'http://127.0.0.1:7890'
+    video_duration_maximum: Optional[int] = 480
